<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads
 *
 * @package   jchoptimize/core
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2022 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 *  If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */
namespace JchOptimize\Core;

use _JchOptimizeVendor\Laminas\Cache\Exception\ExceptionInterface;
use _JchOptimizeVendor\Laminas\Cache\Storage\IterableInterface;
use _JchOptimizeVendor\Laminas\Cache\Storage\TaggableInterface;
trait StorageTaggingTrait
{
    protected function tagStorage($id)
    {
        $storage = $this->callbackCache->getStorage();
        if ($storage instanceof TaggableInterface && $storage instanceof IterableInterface) {
            $this->setStorageTags($storage, $id);
        } else {
            try {
                //If item not already set for tagging, set it
                if (!$this->fsCache->getItem($id)) {
                    $this->fsCache->setItem($id, 'tag');
                }
                //Always attempt to store tags, item could be set on another page
                $this->setStorageTags($this->fsCache, $id);
            } catch (ExceptionInterface $e) {
                //Don't sweat it.
            }
        }
    }
    private function setStorageTags(TaggableInterface $cache, string $id)
    {
        $tags = $cache->getTags($id);
        $currentUrl = \JchOptimize\Core\SystemUri::toString();
        //If current url not yet tagged, tag it for this item
        if (\is_array($tags) && !\in_array($currentUrl, $tags)) {
            $cache->setTags($id, \array_merge($tags, [$currentUrl]));
        }
    }
}
